.. module:: enaml.widgets.mdi_window

========================
enaml.widgets.mdi_window
========================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    MdiWindow


.. autoclass:: MdiWindow
